@@ -1,5 +1,5 @@
 from .version import __version__
-from .request.http import HTTPClient, Route
+from .request import HTTPClient, Route, ResponseStatusCode, ResponseParser
 from .components import Components, RemoveComponents, InlineKeyboard, Keyboard
 from .attachments.audio import Audio
 from .attachments.location import Location
@@ -14,8 +14,8 @@ from .permissions import AdminPermissions
 from .chatmember import ChatMember, MemberRole
 from .callbackquery import CallbackQuery
 from .update import Update
-from .updater import Updater
-from .error import BaleError, APIError
+from .updater import Updater, EventType
+from .error import BaleError, APIError, NetworkError, HTTPException, TimeOut, NotFound, Forbidden, HTTPClientError, InvalidToken
 from .bot import Bot
 
 
@@ -28,6 +28,7 @@ __all__ = (
     "Message",
     "User",
     "Updater",
+    "EventType",
     "Components",
     "RemoveComponents",
     "Keyboard",
@@ -39,13 +40,22 @@ __all__ = (
     "ContactMessage",
     "Invoice",
     "Price",
-    "HTTPClient",
-    "Route",
+    "AdminPermissions",
+    "ChatMember",
+    "MemberRole",
     "BaleError",
     "APIError",
-    "AdminPermissions",
-    "ChatMember", 
-    "MemberRole"
+    "InvalidToken",
+    "Forbidden",
+    "NetworkError",
+    "TimeOut",
+    "NotFound",
+    "HTTPException",
+    "HTTPClientError",
+    "HTTPClient",
+    "Route",
+    "ResponseParser",
+    "ResponseStatusCode",
 )
 
 __title__ = "python-bale-bot"
