@@ -1,4 +1,19 @@
 class Audio:
+    """This object shows a waist.
+
+    Attributes
+    ----------
+        file_id: str
+            Audio ID
+        duration: int
+            Audio duration
+        file_size: unt
+            Audio Size.
+        mime_type: Optional[:class:`str`]
+            Audio Mime type.
+        title: Optional[:class:`str`]
+            Audio Title.
+    """
     __slots__ = (
         "file_id",
         "duration",
@@ -8,16 +23,7 @@ class Audio:
         "bot"
     )
 
-    def __init__(self, file_id: id, duration: int, file_size: int = None, mime_type: str = None, title: str = None):
-        """This object shows a waist
-
-        Args:
-            file_id (id): Audio ID
-            duration (int): Audio duration
-            file_size (int): Audio Size. Defaults to None.
-            mime_type (str): Audio Mime type. Defaults to None.
-            title (str): Audio Title. Defaults to None.
-        """
+    def __init__(self, file_id: str, duration: int, file_size: int = None, mime_type: str = None, title: str = None):
         self.file_id = file_id
         self.duration = duration
 
@@ -27,10 +33,6 @@ class Audio:
 
     @classmethod
     def from_dict(cls, data):
-        """
-        Args:
-            data (dict): Data
-        """
         return cls(file_id=data["file_id"], duration=data["duration"], file_size=data["file_size"], title=data["title"],
                    mime_type=data["mime_type"])
 
@@ -41,8 +43,4 @@ class Audio:
                 "file_size": self.file_size if self.file_size is not None else None,
                 "mime_type": self.mime_type if self.mime_type is not None else None}
 
-        return data
-
-    def get_file(self):
-        # Coming Soon...
-        pass
+        return data
\ No newline at end of file
