@@ -34,22 +34,34 @@ from bale import (Chat, User, Document, ContactMessage, Photo, Invoice)
 
 
 class Message:
-    """This object shows a message
+    """This object shows a message.
 
-    Args:
-        message_id (str): Message ID.
-        date (datetime.datetime): When the message has been sent.
-        text (str): Message Text. Defaults to None.
-        caption (str): Message caption. Defaults to None.
-        from_user (:class:`bale.User`): The user who has sent the message. Defaults to None.
-        forward_from (:class:`bale.User`) no description. Defaults to None.
-        contact (:class:`bale.ContactMessage`): Defaults to None.
-        chat (:class:`bale.Chat`): The chat where the message is sent. Defaults to None.
-        reply_to_message (:class:`bale.Message`)
-        new_chat_members (:class:`bale.User`): User (An) who entered the chat. Defaults to None.
-        left_chat_member (:class:`bale.User`): A user out of chat. Defaults to None.
-        invoice (:class:`bale.Invoice`): Message invoice.
-        bot (:class:`bale.Bot`): Bot object. Defaults to None.
+    Attributes
+    ----------
+        message_id: str
+            Message ID.
+        date: :class:`datetime.datetime`
+            When the message has been sent.
+        text: Optional[:class:`str`]
+            Message Content
+        caption: Optional[:class:`str`]
+            Message caption.
+        from_user: Optional[:class:`bale.User`]
+            The user who has sent the message.
+        forward_from: Optional[:class:`bale.User`]
+            The user who has sent the message originally.
+        contact: Optional[:class:`bale.ContactMessage`]
+            Contact
+        chat: :class:`bale.Chat`
+            The chat where the message is sent.
+        reply_to_message: Optional[:class:`bale.Message`]
+            The message Replayed to who message.
+        new_chat_members: Optional[List[:class:`bale.User`]]
+            User (An) who entered the chat.
+        left_chat_member: Optional[:class:`bale.User`]
+            A user out of chat.
+        invoice: Optional[:class:`bale.Invoice`]
+            Message invoice.
     """
     __slots__ = (
         "text", "caption", "from_user", "_author", "contact", "chat", "message_id", "forward_from", "forward_from_message_id", "date_code", "date", "edit_date",
@@ -57,7 +69,7 @@ class Message:
         "reply_to_message", "invoice", "bot"
     )
 
-    def __init__(self, message_id: str, date: datetime, text: str = None, caption: str = None,
+    def __init__(self, message_id: str, date: datetime, *, text: str = None, caption: str = None,
                  forward_from: "User" = None, forward_from_message_id: str = None, from_user: "User" = None, document: "Document" = None, contact: "ContactMessage" = None, chat: "Chat" = None,
                  photos: List["Photo"] = None, reply_to_message: "Message" = None, invoice: "Invoice" = None, bot: 'Bot' = None, **options):
         self.message_id: str = message_id if message_id is not None else None
@@ -117,11 +129,6 @@ class Message:
 
     @classmethod
     def from_dict(cls, data: dict, bot):
-        """
-        Args:
-            data (dict): Data
-            bot (:class:`bale.Bot`): Bot
-        """
         options = {}
         if data.get("new_chat_members"):
             options["new_chat_members"] = [User.from_dict(bot=bot, data=i) for i in data.get("new_chat_members")]
@@ -165,50 +172,84 @@ class Message:
 
         return data
 
-    async def reply(self, text: str, components=None):
-        """:meth:`bale.Bot.send_message`
+    async def reply(self, text: str, *, components=None):
+        """
+        For the documentation of the arguments, please see :meth:`bale.Bot.send_message`.
 
-        Args:
-            text (str): Message Text.
-            components (:class:`bot.Components`|:class:`bale.RemoveComponents`): Message Components.
-        Raises:
+        Parameters
+        ----------
+            text: str
+                Message Content.
+            components: Optional[:class:`bot.Components` | :class:`bale.RemoveComponents`]
+                Message Components.
+        Raises
+        ------
             :class:`bale.Error`
-        Returns:
-            :class:`bale.Message`: On success, the sent Message is returned."""
-        result = await self.bot.send_message(chat=self.chat, text=text, components=components,
-                                       reply_to_message_id=str(self.message_id) if not self.chat.type.is_group_chat() else None)
-        return result
+        Returns
+        -------
+            :class:`bale.Message`
+                On success, the sent Message is returned.
+        """
+        message = await self.bot.send_message(chat=self.chat, text=text, components=components,
+                                       reply_to_message=self if not self.chat.type.is_group_chat() else None)
+        return message
 
     async def reply_photo(self, photo: bytes | str, caption: str = None):
-        """:meth:`bale.Bot.send_photo`
+        """
+        For the documentation of the arguments, please see :meth:`bale.Bot.send_photo`.
 
-        Args:
-            photo (:class:`bytes`|:class:`str`): Photo.
-            caption (:class:`str`): Message caption.
-        Raises:
+        Parameters
+        ----------
+            photo: :class:`bytes` | :class:`str`
+                Photo
+            caption: Optional[:class:`str`]
+                Message caption
+        Raises
+        ------
             :class:`bale.Error`
-        Returns:
-            :class:`bale.Message`: On success, the sent Message is returned."""
-        message = await self.bot.send_photo(self.chat, photo, caption, reply_to_message_id=str(self.message_id) if not self.chat.type.is_group_chat() else None)
+        Returns
+        -------
+            :class:`bale.Message`:
+                On success, the sent Message is returned.
+        """
+        message = await self.bot.send_photo(self.chat, photo, caption=caption, reply_to_message=self if not self.chat.type.is_group_chat() else None)
         return message
 
     async def reply_invoice(self, title: str, description: str, provider_token: str, prices, photo_url=None, need_name=False,
                       need_phone_number=False, need_email=False, need_shipping_address=False, is_flexible=True):
-        """:meth:`bale.Bot.send_invoice`
+        """
+        For the documentation of the arguments, please see :meth:`bale.Bot.send_invoice`
 
-        Args:
-            title (str): Invoice Title
-            description (str): Invoice Description
-            provider_token (str): You can use 3 methods to receive money: 1.Card number 2. Port number and acceptor number 3. Wallet number "Bale"
-            prices (List[:class:`bale.Price`]): A list of prices.
-            photo_url (str): Photo URL of Invoice. Defaults to None.
-            need_name (bool): Get a name from "User"?. Defaults to False.
-            need_phone_number (bool): Get a Phone number from "User"?. Defaults to False.
-            need_email (bool): Get a Email from "User"?. Defaults to False.
-            need_shipping_address (bool): Get a Shipping Address from "User"?. Defaults to False.
-            is_flexible (bool): Is the Invoice Photo Flexible to the Payment button?. Defaults to True.
-        Returns:
-            :class:`Bale.Message`
+        Parameters
+        ----------
+            title: str
+                Invoice Title
+            description: str
+                Invoice Description
+            provider_token: str
+                .. note::
+                    You can use 3 methods to receive money:
+                        * Card number
+                        * Port number and acceptor number
+                        * Wallet number "Bale"
+            prices: List[:class:`bale.Price`]
+                A list of prices.
+            photo_url: Optional[:class:`str`]
+                Photo URL of Invoice.
+            need_name: Optional[:class:`bool`]
+                Get a name from "User"?
+            need_phone_number: Optional[:class:`bool`]
+                Get a Phone number from "User"?.
+            need_email: Optional[bool]
+                Get a Email from "User"?.
+            need_shipping_address: Optional[bool]
+                Get a Shipping Address from "User"?.
+            is_flexible: Optional[bool]
+                Is the Invoice Photo Flexible to the Payment button?
+        Returns
+        -------
+            :class:`Bale.Message`:
+                On success, the message sent returned.
         """
         message = await self.bot.send_invoice(chat=self.chat, title=title, description=description,
                                         provider_token=provider_token, prices=prices, photo_url=photo_url,
@@ -217,27 +258,36 @@ class Message:
         return message
 
     async def edit(self, text: str = None, components=None):
-        """:meth:`bale.Bot.edit_message`
+        """
+        For the documentation of the arguments, please see :meth:`bale.Bot.edit_message`
 
-        Args:
-            text (str): New Content For Message.
-            components (:class:`bale.Components`|:class:`bale.RemoveComponents`): Components.
-        Raises:
+        Parameters
+        ----------
+            text: str
+                New Content for message.
+            components: Optional[:class:`bale.Components` | :class:`bale.RemoveComponents`]
+                New Message Components for message.
+        Raises
+        ------
             :class:`bale.Error`
-        Return:
+        Return
+        ------
             :class:`dict`
         """
-        result = await self.bot.edit_message(self.chat, self.message_id, text, components)
+        result = await self.bot.edit_message(self.chat, self, text, components=components)
         self.text = text
         return result
 
     async def delete(self):
-        """:meth:`bale.Bot.delete_message`
-
-        Return:
-            bool: if done "True" if not "False"
         """
-        message = await self.bot.delete_message(chat=self.chat, message_id=str(self.message_id))
+        For the documentation of the arguments, please see :meth:`bale.Bot.delete_message`.
+
+        Return
+        ------
+            bool:
+                ``True`` when user added to chat else ``False``
+        """
+        message = await self.bot.delete_message(self.chat, self)
         return message
 
     def __str__(self):
