@@ -27,8 +27,17 @@ if TYPE_CHECKING:
 
 __all__ = (
 	"Updater",
+	"EventType"
 )
 
+class EventType:
+	READY = "on_ready"
+	UPDATE = "on_update"
+	MESSAGE = "on_message"
+	CALLBACK = "on_callback"
+	MEMBER_CHAT_JOIN = "on_member_chat_join"
+	MEMBER_CHAT_LEAVE = "on_member_chat_leave"
+
 class Updater:
 	"""This object represents a Bale Bot.
 
@@ -46,7 +55,8 @@ class Updater:
 		"bot",
 		"update_queue",
 		"_last_offset",
-		"_is_running"
+		"_is_running",
+		"sleep_after_get_updates"
 	)
 
 	def __init__(self, bot: "Bot"):
@@ -54,11 +64,14 @@ class Updater:
 		self.update_queue = asyncio.Queue()
 		self._last_offset = None
 		self._is_running = False
+		self.sleep_after_get_updates = None
 
-	async def start(self):
+	async def start(self, sleep_after_every_get_updates: int = None):
 		"""Start poll event function"""
 		if self._is_running:
 			raise RuntimeError("Updater is running")
+		if sleep_after_every_get_updates is not None:
+			self.sleep_after_get_updates = sleep_after_every_get_updates
 		self._is_running = True
 		self.bot.dispatch("ready")
 		await self.poll_event()
@@ -69,10 +82,13 @@ class Updater:
 			raise RuntimeError("Updater is running")
 		while self._is_running:
 			if self.bot.is_closed():
-				raise RuntimeError("Bot is Closed!")
+				raise RuntimeError("Bot is Closed")
+
+			if self.bot.http.is_closed():
+				raise RuntimeError("HTTPClient is Closed")
 
 			if not self._is_running:
-				raise RuntimeError("Updater is not running")
+				break
 
 			updates = await self.bot.get_updates(offset=self._last_offset)
 
@@ -90,6 +106,9 @@ class Updater:
 
 			self._last_offset = updates[-1].update_id if bool(updates) else self._last_offset
 
+			if self.sleep_after_get_updates is not None:
+				await asyncio.sleep(self.sleep_after_get_updates)
+
 	def stop(self):
 		"""Stop running and Stop `poll_event` loop"""
 		if not self._is_running:
