@@ -25,17 +25,18 @@
 from __future__ import annotations
 from typing import TYPE_CHECKING
 if TYPE_CHECKING:
-    from bale import Bot, Photo
+    from bale import Bot, Photo, Document
 
 
 class User:
     """This object shows a user.
-        Args:
-            user_id (int): User ID.
-            first_name (str): first user name
-            last_name (str): last user name. Defaults to None.
-            username (str): Username of the user. Defaults to None.
-            bot (:class:`bale.Bot`): Bot Object. Defaults to None.
+
+    Attributes
+    ----------
+        user_id: int
+        first_name: str
+        last_name: str
+        username: Optional[:class:`str`]
     """
     __slots__ = (
         "first_name",
@@ -54,68 +55,75 @@ class User:
 
     @property
     def mention(self) -> str | None:
-        """Mention User"""
+        """Optional[:class:`str`]"""
         return f"@{self.username}" if self.username else None
 
     @property
-    def link(self):
-        """Get user link in bale"""
-        if self.username:
-            return "https://ble.ir/@{username}".format(username=self.username)
-        return None
+    def chat_id(self) -> str:
+        """:class:`str`"""
+        return str(self.user_id)
 
     async def send(self, text: str, components=None):
-        """Send a Text Message to User
-
-        Args:
-            text (str): Message Text.
-            components (:class:`bale.Components`|:class:`bale.RemoveComponents`): Message Components. Defaults to None.
-        Returns:
-            :class:`bale.Message`
         """
-        from bale import Message
-        if components:
-            components = components.to_dict()
-        response, payload = await self.bot.http.send_message(str(self.user_id), text, components=components)
-        return Message.from_dict(data=payload["result"], bot=self.bot)
+        For the documentation of the arguments, please see :meth:`bale.Bot.send_message`.
+
+        Parameters
+        ----------
+            text: str
+                Message Content
+            components: :class:`bale.Components` | :class:`bale.RemoveComponents`
+                Message Components
+        Returns
+        -------
+            :class:`bale.Message`
+                On success, the sent Message is returned.
+        """
+        return await self.bot.send_message(self, text, components)
+
+    async def send_document(self, document: bytes | str | "Document", caption: str = None):
+        """For the documentation of the arguments, please see :meth:`bale.Bot.send_document`.
+
+        Parameters
+        ----------
+            document: :class:`bytes` | :class:`str` | :class:`bale.Document`
+                Photo
+            caption: :class:`str`
+                Message caption
+        Raises
+        ------
+            :class:`bale.Error`
+        Returns
+        -------
+            :class:`bale.Message`
+                On success, the sent Message is returned.
+        """
+        return await self.bot.send_document(self, document, caption)
 
     async def send_photo(self, photo: bytes | str | "Photo", caption: str = None):
-        """This service is used to send photo.
+        """For the documentation of the arguments, please see :meth:`bale.Bot.send_photo`.
 
-        Args:
-            photo (:class:`bytes`|:class:`str`|:class:`bale.Photo`): Photo.
-            caption (:class:`str`): Message caption.
-        Raises:
+        Parameters
+        ----------
+            photo: :class:`bytes` | :class:`str` | :class:`bale.Photo`
+                Photo
+            caption: :class:`str`
+                Message caption
+        Raises
+        ------
             :class:`bale.Error`
-        Returns:
-            :class:`bale.Message`: On success, the sent Message is returned.
+        Returns
+        -------
+            :class:`bale.Message`
+                On success, the sent Message is returned.
         """
-        from bale import Message
-        if not isinstance(photo, (bytes, str, Photo)):
-            raise TypeError(
-                f"photo is not a str or bytes or bale.Photo. this is a {photo.__class__} !"
-            )
-
-        if isinstance(photo, Photo):
-            photo = photo.file_id
-        response, payload = await self.bot.http.send_photo(str(self.user_id), photo, caption)
-        return Message.from_dict(data=payload["result"], bot=self.bot)
+        return await self.bot.send_photo(self, photo, caption)
 
     @classmethod
     def from_dict(cls, data: dict, bot=None):
-        """
-        Args:
-            data (dict): Data
-            bot (:class:`bale.Bot`): Bot
-        """
         return cls(username=data.get("username"), first_name=data.get("first_name"), last_name=data.get("last_name"),
                    user_id=data.get("id"), bot=bot)
 
     def to_dict(self):
-        """Convert Class to dict
-        Returns:
-            :dict:
-        """
         data = {"first_name": self.first_name if self.first_name is not None else None,
                 "last_name": self.last_name if self.last_name is not None else None,
                 "username": self.username if self.username is not None else None,
